@@ -1,4 +1,5 @@
 from . import client, server
+import json, socket
 
 class ScenarioTerminatedException(Exception):
   "The scenario is ended by the user forcibly."
@@ -24,7 +25,7 @@ class Scenario:
 
   def _init_scenario(self, j):
     self.srv.server_socket.settimeout(5)
-    j2 = j + {"sready": True, "saddr": self.srv.host, "sport": self.srv.port}
+    j |= {"sready": True, "saddr": self.srv.host, "sport": self.srv.port}
     self.cli._send(Scenario._encode_json(j))
     res = Scenario._decode_json(self.srv._waits_for())
     self.srv.server_socket.settimeout(None)
@@ -34,14 +35,14 @@ class Scenario:
     self.init = True
  
   def _continue_scenario(self, j):
-    j2 = j + {"stoken": self.token, "scontinue": True}
-    self.cli._send(Scenario._encode_json(j2))
+    j |= {"stoken": self.token, "scontinue": True}
+    self.cli._send(Scenario._encode_json(j))
     
   def _terminate_scenario(self, j):
-    j2 = j + {"stoken": self.token, "sfinish": True}
+    j |= {"stoken": self.token, "sfinish": True}
     self.token = None
     self.init = False
-    self.cli._send(Scenario._encode_json(j2))
+    self.cli._send(Scenario._encode_json(j))
 
   def _decide(self, j):
     if self.init:
